pub enum AuthFlowError {
BadResponse {
msg: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
Aborted {
msg: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
Internal {
msg: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
}Variants
BadResponse
The data provided in the server callback, or the callback URL itself, was malformed or incomplete
Aborted
Authentication was aborted. For example by a timeout or the user canceling the authentication
Internal
An internal error. For example, failure to launch the browser or to read user input from the console.