pub enum ClientConnectError {
AuthError {
msg: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
AuthHandlerError(AuthFlowError),
ConnectionError {
msg: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
}Expand description
Errors that occur when connecting the client.
Variants
AuthError
A step of the authentication process failed.
AuthHandlerError(AuthFlowError)
A step of the authentication process failed, inside the authentication handler.
AuthFlowError::Aborted
can indicate that the user cancelled or failed the authentication
steps.
ConnectionError
Failed to set up a connection to the MCP servic.